@@ -8,9 +8,15 @@ from bigquery.job.ems_load_job import EmsLoadJob
 class TestEmsLoadJob(TestCase):
 
     def setUp(self):
-        self.load_config = EmsLoadJobConfig(schema={"fields": [{"type": "INT64", "name": "f"}]}, source_uri_template="")
-        error_result = {"some": "error", "happened": "here"}
-        self.ems_load_job = EmsLoadJob("test-job-id", self.load_config, EmsJobState.DONE, error_result)
+        self.expected_error_result =  {"some": "error", "happened": "here"}
+        self.load_config = EmsLoadJobConfig(
+            schema={"fields": [{"type": "INT64", "name": "f"}]},
+            source_uri_template="",
+            destination_project_id="dummy-project-id",
+            destination_dataset="dummy-dataset",
+            destination_table="dummy-project-id.dummy-dataset.dummy-table"
+        )
+        self.ems_load_job = EmsLoadJob("test-job-id", self.load_config, EmsJobState.DONE, self.expected_error_result)
 
     def test_state(self):
         self.assertEqual(self.ems_load_job.state, EmsJobState.DONE)
@@ -25,3 +31,6 @@ class TestEmsLoadJob(TestCase):
         not_failed_ems_load_job = EmsLoadJob("test-job-id", self.load_config, EmsJobState.DONE, None)
 
         self.assertFalse(not_failed_ems_load_job.is_failed)
+
+    def test_error_result(self):
+        self.assertEqual(self.ems_load_job.error_result, self.expected_error_result)
